function [ Kl,Cl,Ml ] = elmt23( local_data )
% elmt23: 2-D three-node (triangular) element for Navier-Stokes flow  
% (Constant gradient triangle, etc.)
%
%Element subroutine to construct local element matrix from local data
%
%  local_data.mater = [elt# Density Viscosity Thickness prop4 prop5 ] For material type
%
%  local_data.coords = [ x1 x2 of node 1;
%                        x1 x2 of node 2;
%                        x1 x2 of node 3]
%
%  local_data.dofs   = [ dof1 dof2 dof3] Global dof referenced to local dofs
%
  Kl = zeros(9,9);
  Cl = zeros(9,9);
  Ml = zeros(9,9);
  D  = zeros(2,2);
  A  = zeros(2,3);
%
%  Constitutive matrix - Darcy's Law, Fick's Law, Four
%
  density      = local_data.mater(1,2);
  viscosity    = local_data.mater(1,3);
  thickness    = 1
  
%-------------------------------- Evaluate coefs and determinant for element area
    b = local_data.coords(2,1)*local_data.coords(3,2) - local_data.coords(3,1)*local_data.coords(2,2);
    b21 = local_data.coords(2,2) - local_data.coords(3,2);
    b31 = local_data.coords(3,1) - local_data.coords(2,1);
    d2  = local_data.coords(1,1)*b21 + local_data.coords(1,2)*b31 + b;
    area = d2/2;
%-------------------------------- Evaluate derivatives of shape functions
A = (1/d2) * [ b21  (local_data.coords(3,2)-local_data.coords(1,2))  (local_data.coords(1,2)-local_data.coords(2,2));
               b31  (local_data.coords(1,1)-local_data.coords(3,1))  (local_data.coords(2,1)-local_data.coords(1,1))];

%-------------------------------- Evaluate second order matrices 
    D = [ 1 0; 0 0 ];  secondorderinx = zeros(3,3); secondorderinx = A'*(D*A)*area*thickness
    D = [ 0 0; 0 1 ];  secondorderiny = zeros(3,3); secondorderiny = A'*(D*A)*area*thickness
    
%-------------------------------- Evaluate first order matrices 
    factor = ones(3,1)/3
    v = [ 1; 0 ];      firstorderinx = zeros(3,3);  firstorderinx = factor*(v'*A)*area*thickness
    v = [ 0; 1 ];      firstorderiny = zeros(3,3);  firstorderiny = factor*(v'*A)*area*thickness
    
%-------------------------------- Assemble local stiffness matrix [ vx1 vx2 vx3 vy1 vy2 vy3 p1 p2 p3 ]
    null = zeros(3,3)
    
    Kl = [ viscosity*(secondorderinx+secondorderiny)   null                                         firstorderinx ; 
           null                                        viscosity*(secondorderinx+secondorderiny)    firstorderiny;
           firstorderinx'                              firstorderiny'                               null ]
    
%-------------------------------- Reorder stiffness matrix for dof
% [vx1 vx2 vx3 vy1 vy2 vy3 p1 p2 p3] ==> [vx1 vy1 p1 vx2 vy2 p2 vx3 vy3 p3]

% ----- Reorder columns  
            tempcol = Kl(:,2); Kl(:,2) = Kl(:,4); Kl(:,4) = tempcol;
            tempcol = Kl(:,3); Kl(:,3) = Kl(:,7); Kl(:,7) = tempcol;
            tempcol = Kl(:,6); Kl(:,6) = Kl(:,8); Kl(:,8) = tempcol;
% ----- Reorder rows
            temprow = Kl(2,:); Kl(2,:) = Kl(4,:); Kl(4,:) = temprow;
            temprow = Kl(3,:); Kl(3,:) = Kl(7,:); Kl(7,:) = temprow; 
            temprow = Kl(6,:); Kl(6,:) = Kl(8,:); Kl(8,:) = temprow;
            
%-------------------------------- Evalaute consistent mass (storage) matrix
%    Cl = (area*thickness/3) * [ 1 0 0; 0 1 0; 0 0 1];

         
         
